aboutsummaryrefslogtreecommitdiff
path: root/stdlib/tst-strtol-binary-c2x.c
diff options
context:
space:
mode:
Diffstat (limited to 'stdlib/tst-strtol-binary-c2x.c')
-rw-r--r--stdlib/tst-strtol-binary-c2x.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/stdlib/tst-strtol-binary-c2x.c b/stdlib/tst-strtol-binary-c2x.c
index 2237f3a227..5e2b6dd6a0 100644
--- a/stdlib/tst-strtol-binary-c2x.c
+++ b/stdlib/tst-strtol-binary-c2x.c
@@ -1,4 +1,4 @@
/* Test strtol functions with C2X binary integers (narrow strings,
no extensions).
Copyright (C) 2022-2024 Free Software Foundation, Inc.
This file is part of the GNU C Library.
@@ -18,15 +18,15 @@
<https://www.gnu.org/licenses/>. */
/* Some versions of GCC supported for building glibc do not support
- -std=c2x. */
+ -std=c23 or -std=c2x. */
#undef _GNU_SOURCE
-#define _ISOC2X_SOURCE
+#define _ISOC23_SOURCE
#define CHAR char
#define WIDE 0
#define FNPFX strto
#define L_(C) C
-#define TEST_C2X 1
+#define TEST_C23 1
#define TEST_Q 0
#define TEST_LOCALE 0
@@ -1,4 +1,4 @@
-/* Test strtol functions with C2X binary integers (narrow strings,
+/* Test strtol functions with C23 binary integers (narrow strings,
no extensions).
Copyright (C) 2022-2024 Free Software Foundation, Inc.